@@ -63,6 +63,26 @@ class TestJaJp:
             assert pattern.fullmatch(phone_number)
 
 
+class TestCsCz:
+    """Test cs_CZ phone number provider methods"""
+
+    def test_phone_number(self, faker, num_samples):
+        pattern: Pattern = re.compile(r"^(00420|\+420)? ?[1-9][0-9]{2} ?[0-9]{3} ?[0-9]{3}$")
+        for _ in range(num_samples):
+            phone_number = faker.phone_number()
+            assert pattern.fullmatch(phone_number)
+
+
+class TestSkSk:
+    """Test sk_SK phone number provider methods"""
+
+    def test_phone_number(self, faker, num_samples):
+        pattern: Pattern = re.compile(r"^(00421|\+421)? ?[2-9][0-9]{2} ?[0-9]{3} ?[0-9]{3}$")
+        for _ in range(num_samples):
+            phone_number = faker.phone_number()
+            assert pattern.fullmatch(phone_number)
+
+
 class TestPtBr:
     """Test pt_BR phone number provider methods"""
 
@@ -363,7 +383,14 @@ class TestFrFr:
         ]
         for _ in range(num_samples):
             phone_number = faker.phone_number()
-            assert any([re.match(pattern, phone_number) for pattern in patterns])
+
+            pattern_is_found = False
+
+            for pattern in patterns:
+                if re.match(pattern, phone_number):
+                    pattern_is_found = True
+                    break
+            assert pattern_is_found
 
 
 class TestEnUs:
@@ -378,4 +405,10 @@ class TestEnUs:
         patterns = [pattern_no_whitespaces, pattern_dashes, pattern_parens]
         for _ in range(num_samples):
             phone_number = faker.basic_phone_number()
-            assert any([re.match(pattern, phone_number) for pattern in patterns])
+
+            pattern_is_found = False
+            for pattern in patterns:
+                if re.match(pattern, phone_number):
+                    pattern_is_found = True
+                    break
+            assert pattern_is_found
